@@ -26,7 +26,7 @@ def Location_Type(x:str):
         return x
     
 
-def CSC_Prob(text:str):
+def CSC_Prob(text:str,my_cliff):
     
     """"
     input: TDC_Geo, which is cleaned news for geolocator
@@ -142,14 +142,14 @@ def CSC_Prob(text:str):
                 return geo_details
             
 
-def Get_CSC_Prob(dataset):
+def Get_CSC_Prob(dataset,my_cliff):
     
     """ To calculate the geo info of multiple news articles and store in a big dataframe"""
     
     
     CSCs = pd.DataFrame()
     for i in tqdm(dataset.index):
-        csc_prob = CSC_Prob(dataset.TDC_Geo[i])
+        csc_prob = CSC_Prob(dataset.TDC_Geo[i],my_cliff)
         csc_prob['news_id'] = dataset.news_id[i]                    
         CSCs = pd.concat([CSCs, csc_prob],ignore_index=True)
         
